// src/use-pagination-item.ts
import { useMemo } from "react";
import { PaginationItemType } from "@nextui-org/use-pagination";
import { ringClasses } from "@nextui-org/theme";
import { clsx, dataAttr, warn } from "@nextui-org/shared-utils";
import { mergeProps } from "@react-aria/utils";
import { useDOMRef } from "@nextui-org/dom-utils";
import { usePress } from "@react-aria/interactions";
import { useFocusRing } from "@react-aria/focus";
var getItemAriaLabel = (page) => {
  if (!page)
    return;
  switch (page) {
    case PaginationItemType.DOTS:
      return "dots element";
    case PaginationItemType.PREV:
      return "previous page button";
    case PaginationItemType.NEXT:
      return "next page button";
    case "first":
      return "first page button";
    case "last":
      return "last page button";
    default:
      return `pagination item ${page}`;
  }
};
function usePaginationItem(props) {
  const {
    as,
    ref,
    value,
    children,
    isActive,
    isDisabled,
    onPress,
    onClick,
    getAriaLabel = getItemAriaLabel,
    className,
    ...otherProps
  } = props;
  const Component = as || "li";
  const domRef = useDOMRef(ref);
  const ariaLabel = useMemo(
    () => isActive ? `${getAriaLabel(value)} active` : getAriaLabel(value),
    [value, isActive]
  );
  const handlePress = (e) => {
    if (onClick) {
      warn("onClick is deprecated, use onPress instead.", "PaginationItem");
    }
    onPress == null ? void 0 : onPress(e);
  };
  const { pressProps } = usePress({
    isDisabled,
    onPress: handlePress
  });
  const { focusProps, isFocused, isFocusVisible } = useFocusRing();
  const getItemProps = (props2 = {}) => {
    return {
      ref: domRef,
      role: "button",
      tabIndex: isDisabled ? -1 : 0,
      "aria-label": ariaLabel,
      "aria-current": dataAttr(isActive),
      "aria-disabled": dataAttr(isDisabled),
      "data-active": dataAttr(isActive),
      "data-focus-visible": dataAttr(isFocusVisible),
      "data-focused": dataAttr(isFocused),
      className: clsx(isFocusVisible && [...ringClasses], className),
      ...mergeProps(props2, pressProps, focusProps, otherProps)
    };
  };
  return {
    Component,
    children,
    ariaLabel,
    isFocused,
    isFocusVisible,
    getItemProps
  };
}

export {
  usePaginationItem
};
