// src/use-pagination.ts
import { useEffect, useRef, useMemo } from "react";
import { mapPropsVariants } from "@nextui-org/system";
import { usePagination as useBasePagination } from "@nextui-org/use-pagination";
import { pagination } from "@nextui-org/theme";
import { useDOMRef } from "@nextui-org/dom-utils";
import { clsx, dataAttr } from "@nextui-org/shared-utils";
var CURSOR_TRANSITION_TIMEOUT = 300;
function usePagination(originalProps) {
  const [props, variantProps] = mapPropsVariants(originalProps, pagination.variantKeys);
  const {
    as,
    ref,
    classNames,
    dotsJump = 5,
    loop = false,
    showControls = false,
    total = 1,
    initialPage = 1,
    page,
    siblings,
    boundaries,
    onChange,
    className,
    renderItem,
    ...otherProps
  } = props;
  const Component = as || "ul";
  const domRef = useDOMRef(ref);
  const cursorRef = useRef(null);
  const itemsRef = useRef();
  const cursorTimer = useRef();
  function getItemsRefMap() {
    if (!itemsRef.current) {
      itemsRef.current = /* @__PURE__ */ new Map();
    }
    return itemsRef.current;
  }
  function getItemRef(node, value) {
    const map = getItemsRefMap();
    if (node) {
      map.set(value, node);
    } else {
      map.delete(value);
    }
  }
  function scrollTo(value) {
    const map = getItemsRefMap();
    const node = map.get(value);
    cursorTimer.current && clearTimeout(cursorTimer.current);
    if (node) {
      const { offsetLeft } = node;
      if (cursorRef.current) {
        cursorRef.current.setAttribute("data-moving", "true");
        cursorRef.current.style.transform = `translateX(${offsetLeft}px) scale(1.1)`;
      }
      cursorTimer.current = setTimeout(() => {
        if (cursorRef.current) {
          cursorRef.current.setAttribute("data-moving", "false");
          cursorRef.current.style.transform = `translateX(${offsetLeft}px) scale(1)`;
        }
        cursorTimer.current && clearTimeout(cursorTimer.current);
      }, CURSOR_TRANSITION_TIMEOUT);
    }
  }
  const { range, activePage, setPage, previous, next, first, last } = useBasePagination({
    page,
    total,
    initialPage,
    siblings,
    boundaries,
    showControls,
    onChange
  });
  useEffect(() => {
    if (activePage && !originalProps.disableAnimation) {
      scrollTo(activePage);
    }
  }, [
    activePage,
    originalProps.disableAnimation,
    originalProps.isCompact,
    originalProps.disableCursor
  ]);
  const slots = useMemo(
    () => pagination({
      ...variantProps,
      disableCursor: originalProps.disableCursor || originalProps.disableAnimation
    }),
    [...Object.values(variantProps)]
  );
  const baseStyles = clsx(classNames == null ? void 0 : classNames.base, className);
  const onNext = () => {
    if (loop && activePage === total) {
      return first();
    }
    return next();
  };
  const onPrevious = () => {
    if (loop && activePage === 1) {
      return last();
    }
    return previous();
  };
  const getBaseProps = (props2 = {}) => {
    return {
      ...props2,
      ref: domRef,
      role: "navigation",
      "data-controls": dataAttr(showControls),
      "data-loop": dataAttr(loop),
      "data-dots-jump": dotsJump,
      "data-total": total,
      "data-active-page": activePage,
      className: slots.base({ class: baseStyles }),
      ...otherProps
    };
  };
  const getItemProps = (props2 = {}) => {
    return {
      ...props2,
      ref: (node) => getItemRef(node, props2.value),
      isActive: props2.value === activePage,
      className: slots.item({ class: classNames == null ? void 0 : classNames.item }),
      onPress: () => {
        if (props2.value !== activePage) {
          setPage(props2.value);
        }
      }
    };
  };
  const getCursorProps = (props2 = {}) => {
    return {
      ...props2,
      ref: cursorRef,
      activePage,
      className: slots.cursor({ class: classNames == null ? void 0 : classNames.cursor })
    };
  };
  return {
    Component,
    showControls,
    dotsJump,
    slots,
    classNames,
    loop,
    total,
    range,
    activePage,
    getItemRef,
    disableCursor: originalProps.disableCursor,
    disableAnimation: originalProps.disableAnimation,
    setPage,
    onPrevious,
    onNext,
    renderItem,
    getBaseProps,
    getItemProps,
    getCursorProps
  };
}

export {
  CURSOR_TRANSITION_TIMEOUT,
  usePagination
};
