import {
  pagination_cursor_default
} from "./chunk-VUBQOX7E.mjs";
import {
  pagination_item_default
} from "./chunk-3OFPX77Q.mjs";
import {
  usePagination
} from "./chunk-C44SLLCM.mjs";

// src/pagination.tsx
import { forwardRef } from "@nextui-org/system";
import { useCallback } from "react";
import { PaginationItemType } from "@nextui-org/use-pagination";
import { ChevronIcon, EllipsisIcon, ForwardIcon } from "@nextui-org/shared-icons";
import { clsx } from "@nextui-org/shared-utils";
import { jsx, jsxs } from "react/jsx-runtime";
var Pagination = forwardRef((props, ref) => {
  const {
    Component,
    dotsJump,
    slots,
    classNames,
    total,
    range,
    loop,
    activePage,
    disableCursor,
    disableAnimation,
    renderItem: renderItemProp,
    onNext,
    onPrevious,
    setPage,
    getItemRef,
    getBaseProps,
    getItemProps,
    getCursorProps
  } = usePagination({ ref, ...props });
  const renderItem = useCallback(
    (value, index) => {
      const isBefore = index < range.indexOf(activePage);
      const key = `${value}-${index}`;
      if (renderItemProp && typeof renderItemProp === "function") {
        return renderItemProp({
          value,
          index,
          activePage,
          isActive: value === activePage,
          isPrevious: value === activePage - 1,
          isNext: value === activePage + 1,
          isFirst: value === 1,
          isLast: value === total,
          onNext,
          onPrevious,
          setPage,
          ref: typeof value === "number" ? (node) => getItemRef(node, value) : void 0,
          className: slots.item({ class: classNames == null ? void 0 : classNames.item })
        });
      }
      if (value === PaginationItemType.PREV) {
        return /* @__PURE__ */ jsx(
          pagination_item_default,
          {
            className: slots.prev({
              class: clsx(
                classNames == null ? void 0 : classNames.prev,
                !loop && activePage === 1 && "opacity-50 pointer-events-none"
              )
            }),
            value,
            onPress: onPrevious,
            children: /* @__PURE__ */ jsx(ChevronIcon, {})
          },
          key
        );
      }
      if (value === PaginationItemType.NEXT) {
        return /* @__PURE__ */ jsx(
          pagination_item_default,
          {
            className: slots.next({
              class: clsx(
                classNames == null ? void 0 : classNames.next,
                !loop && activePage === total && "opacity-50 pointer-events-none"
              )
            }),
            value,
            onPress: onNext,
            children: /* @__PURE__ */ jsx(ChevronIcon, { className: "rotate-180" })
          },
          key
        );
      }
      if (value === PaginationItemType.DOTS) {
        return /* @__PURE__ */ jsxs(
          pagination_item_default,
          {
            className: slots.item({
              class: clsx(classNames == null ? void 0 : classNames.item, "group")
            }),
            value,
            onPress: () => isBefore ? setPage(activePage - dotsJump >= 1 ? activePage - dotsJump : 1) : setPage(activePage + dotsJump <= total ? activePage + dotsJump : total),
            children: [
              /* @__PURE__ */ jsx(EllipsisIcon, { className: "group-hover:hidden" }),
              isBefore ? /* @__PURE__ */ jsx(ForwardIcon, { className: "hidden group-hover:block rotate-180" }) : /* @__PURE__ */ jsx(ForwardIcon, { className: "hidden group-hover:block" })
            ]
          },
          key
        );
      }
      return /* @__PURE__ */ jsx(pagination_item_default, { ...getItemProps({ value }), children: value }, `${value}-${index}`);
    },
    [activePage, dotsJump, getItemProps, loop, range, renderItemProp, slots, classNames, total]
  );
  return /* @__PURE__ */ jsxs(Component, { ...getBaseProps(), children: [
    !disableCursor && !disableAnimation && /* @__PURE__ */ jsx(pagination_cursor_default, { ...getCursorProps() }),
    range.map(renderItem)
  ] });
});
Pagination.displayName = "NextUI.Pagination";
var pagination_default = Pagination;

export {
  pagination_default
};
