import * as tailwind_variants from 'tailwind-variants';
import * as _nextui_org_system from '@nextui-org/system';
import { PropGetter, HTMLNextUIProps } from '@nextui-org/system';
import { PaginationVariantProps, SlotsToClasses, PaginationSlots } from '@nextui-org/theme';
import { Ref, ReactNode } from 'react';
import { PaginationItemValue, UsePaginationProps as UsePaginationProps$1 } from '@nextui-org/use-pagination';

type PaginationItemRenderProps<T extends HTMLElement = HTMLElement> = {
    ref?: Ref<T>;
    value: PaginationItemValue;
    index: number;
    activePage: number;
    isActive: boolean;
    isFirst: boolean;
    isLast: boolean;
    isNext: boolean;
    isPrevious: boolean;
    className: string;
    onNext: () => void;
    onPrevious: () => void;
    setPage: (page: number) => void;
};
interface Props extends Omit<HTMLNextUIProps<"ul">, "onChange"> {
    /**
     * Ref to the DOM node.
     */
    ref?: Ref<HTMLElement>;
    /**
     * Number of pages that are added or subtracted on the '...' button.
     * @default 5
     */
    dotsJump?: number;
    /**
     * Non disable next/previous controls
     * @default false
     */
    loop?: boolean;
    /**
     * Whether the pagination should display controls (left/right arrows).
     * @default true
     */
    showControls?: boolean;
    /**
     * Render a custom pagination item.
     * @param props Pagination item props
     * @returns ReactNode
     */
    renderItem?: <T extends HTMLElement>(props: PaginationItemRenderProps<T>) => ReactNode;
    /**
     * Classname or List of classes to change the classNames of the element.
     * if `className` is passed, it will be added to the base slot.
     *
     * @example
     * ```ts
     * <Pagination classNames={{
     *    base:"base-classes",
     *    wrapper: "wrapper-classes",
     *    prev: "prev-classes", // prev button classes
     *    item: "item-classes",
     *    next: "next-classes", // next button classes
     *    cursor: "cursor-classes", // this is the one that moves when an item is selected
     * }} />
     * ```
     */
    classNames?: SlotsToClasses<PaginationSlots>;
}
type UsePaginationProps = Props & UsePaginationProps$1 & PaginationVariantProps;
declare const CURSOR_TRANSITION_TIMEOUT = 300;
declare function usePagination(originalProps: UsePaginationProps): {
    Component: _nextui_org_system.As<any>;
    showControls: boolean;
    dotsJump: number;
    slots: {
        base: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
        item: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
        prev: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
        next: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
        cursor: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
    };
    classNames: SlotsToClasses<"base" | "item" | "prev" | "next" | "cursor"> | undefined;
    loop: boolean;
    total: number;
    range: PaginationItemValue[];
    activePage: number;
    getItemRef: (node: HTMLElement | null, value: number) => void;
    disableCursor: boolean | undefined;
    disableAnimation: boolean | undefined;
    setPage: (pageNumber: number) => void;
    onPrevious: () => void;
    onNext: () => void;
    renderItem: (<T extends HTMLElement>(props: PaginationItemRenderProps<T>) => ReactNode) | undefined;
    getBaseProps: PropGetter<Record<string, unknown>, _nextui_org_system.DOMAttributes<_nextui_org_system.DOMElement>>;
    getItemProps: PropGetter<Record<string, unknown>, _nextui_org_system.DOMAttributes<_nextui_org_system.DOMElement>>;
    getCursorProps: PropGetter<Record<string, unknown>, _nextui_org_system.DOMAttributes<_nextui_org_system.DOMElement>>;
};
type UsePaginationReturn = ReturnType<typeof usePagination>;

export { CURSOR_TRANSITION_TIMEOUT, PaginationItemRenderProps, UsePaginationProps, UsePaginationReturn, usePagination };
